From 519e26a01b6e6974f9e0edb94b00756af053f7ee Mon Sep 17 00:00:00 2001
From: Heikki Linnakangas <heikki.linnakangas@iki.fi>
Date: Wed, 6 Mar 2024 20:27:57 +0200
Subject: [PATCH v6 7/9] Rename skip_state

I don't want to emphasize the "skipping" part. Rather, it's the state
onwed by the heap_vac_scan_get_next_block() function
---
 src/backend/access/heap/vacuumlazy.c | 32 ++++++++++++++--------------
 1 file changed, 16 insertions(+), 16 deletions(-)

diff --git a/src/backend/access/heap/vacuumlazy.c b/src/backend/access/heap/vacuumlazy.c
index 3f1661cea61..17e06065f7e 100644
--- a/src/backend/access/heap/vacuumlazy.c
+++ b/src/backend/access/heap/vacuumlazy.c
@@ -206,8 +206,8 @@ typedef struct LVRelState
 	int64		missed_dead_tuples; /* # removable, but not removed */
 
 	/*
-	 * Parameters maintained by heap_vac_scan_get_next_block() to manage
-	 * skipping ranges of pages greater than SKIP_PAGES_THRESHOLD.
+	 * State maintained by heap_vac_scan_get_next_block() to manage skipping
+	 * ranges of pages greater than SKIP_PAGES_THRESHOLD.
 	 */
 	struct
 	{
@@ -215,7 +215,7 @@ typedef struct LVRelState
 		BlockNumber next_unskippable_block;
 		/* Next unskippable block's visibility status */
 		bool		next_unskippable_allvis;
-	}			skip;
+	}			get_next_block_state;
 } LVRelState;
 
 /* Struct for saving and restoring vacuum error information. */
@@ -831,7 +831,7 @@ lazy_scan_heap(LVRelState *vacrel)
 	initprog_val[2] = dead_items->max_items;
 	pgstat_progress_update_multi_param(3, initprog_index, initprog_val);
 
-	vacrel->skip.next_unskippable_block = InvalidBlockNumber;
+	vacrel->get_next_block_state.next_unskippable_block = InvalidBlockNumber;
 
 	while (heap_vac_scan_get_next_block(vacrel, blkno + 1,
 										&blkno, &all_visible_according_to_vm, &vmbuffer))
@@ -1079,7 +1079,7 @@ lazy_scan_heap(LVRelState *vacrel)
  * process (and its visibility status).
  *
  * The block number and visibility status of the next unskippable block are set
- * in vacrel->skip->next_unskippable_block and next_unskippable_allvis.
+ * in vacrel->scan_sate->next_unskippable_block and next_unskippable_allvis.
  *
  * The block number and visibility status of the next block to process are set
  * in blkno and all_visible_according_to_vm. heap_vac_scan_get_next_block()
@@ -1115,12 +1115,12 @@ heap_vac_scan_get_next_block(LVRelState *vacrel, BlockNumber next_block,
 		return false;
 	}
 
-	if (vacrel->skip.next_unskippable_block == InvalidBlockNumber ||
-		next_block > vacrel->skip.next_unskippable_block)
+	if (vacrel->get_next_block_state.next_unskippable_block == InvalidBlockNumber ||
+		next_block > vacrel->get_next_block_state.next_unskippable_block)
 	{
 		/* Use local variables for better optimized loop code */
 		BlockNumber rel_pages = vacrel->rel_pages;
-		BlockNumber next_unskippable_block = vacrel->skip.next_unskippable_block;
+		BlockNumber next_unskippable_block = vacrel->get_next_block_state.next_unskippable_block;
 
 		while (++next_unskippable_block < rel_pages)
 		{
@@ -1128,9 +1128,9 @@ heap_vac_scan_get_next_block(LVRelState *vacrel, BlockNumber next_block,
 														   next_unskippable_block,
 														   vmbuffer);
 
-			vacrel->skip.next_unskippable_allvis = mapbits & VISIBILITYMAP_ALL_VISIBLE;
+			vacrel->get_next_block_state.next_unskippable_allvis = mapbits & VISIBILITYMAP_ALL_VISIBLE;
 
-			if (!vacrel->skip.next_unskippable_allvis)
+			if (!vacrel->get_next_block_state.next_unskippable_allvis)
 			{
 				Assert((mapbits & VISIBILITYMAP_ALL_FROZEN) == 0);
 				break;
@@ -1155,7 +1155,7 @@ heap_vac_scan_get_next_block(LVRelState *vacrel, BlockNumber next_block,
 			if (!vacrel->skipwithvm)
 			{
 				/* Caller shouldn't rely on all_visible_according_to_vm */
-				vacrel->skip.next_unskippable_allvis = false;
+				vacrel->get_next_block_state.next_unskippable_allvis = false;
 				break;
 			}
 
@@ -1179,7 +1179,7 @@ heap_vac_scan_get_next_block(LVRelState *vacrel, BlockNumber next_block,
 			}
 		}
 
-		vacrel->skip.next_unskippable_block = next_unskippable_block;
+		vacrel->get_next_block_state.next_unskippable_block = next_unskippable_block;
 
 		/*
 		 * We only skip a range with at least SKIP_PAGES_THRESHOLD consecutive
@@ -1193,16 +1193,16 @@ heap_vac_scan_get_next_block(LVRelState *vacrel, BlockNumber next_block,
 		 * pages then skipping makes updating relfrozenxid unsafe, which is a
 		 * real downside.
 		 */
-		if (vacrel->skip.next_unskippable_block - next_block >= SKIP_PAGES_THRESHOLD)
+		if (vacrel->get_next_block_state.next_unskippable_block - next_block >= SKIP_PAGES_THRESHOLD)
 		{
-			next_block = vacrel->skip.next_unskippable_block;
+			next_block = vacrel->get_next_block_state.next_unskippable_block;
 			if (skipsallvis)
 				vacrel->skippedallvis = true;
 		}
 	}
 
-	if (next_block == vacrel->skip.next_unskippable_block)
-		*all_visible_according_to_vm = vacrel->skip.next_unskippable_allvis;
+	if (next_block == vacrel->get_next_block_state.next_unskippable_block)
+		*all_visible_according_to_vm = vacrel->get_next_block_state.next_unskippable_allvis;
 	else
 		*all_visible_according_to_vm = true;
 
-- 
2.39.2

